@@ -14,7 +14,6 @@ from __future__ import annotations
 
 import warnings
 from io import BytesIO
-from typing import Type
 
 import numpy as np
 import numpy.linalg as npl
@@ -25,10 +24,10 @@ from .arrayproxy import get_obj_dtype
 from .batteryrunners import Report
 from .casting import have_binary128
 from .deprecated import alert_future_error
-from .filebasedimages import SerializableImage
+from .filebasedimages import ImageFileError, SerializableImage
 from .optpkg import optional_package
 from .quaternions import fillpositive, mat2quat, quat2mat
-from .spatialimages import HeaderDataError, ImageFileError
+from .spatialimages import HeaderDataError
 from .spm99analyze import SpmAnalyzeHeader
 from .volumeutils import Recoder, endian_codes, make_dt_codes
 
@@ -90,8 +89,8 @@ header_dtype = np.dtype(header_dtd)
 # datatypes not in analyze format, with codes
 if have_binary128():
     # Only enable 128 bit floats if we really have IEEE binary 128 longdoubles
-    _float128t: Type[np.generic] = np.longdouble
-    _complex256t: Type[np.generic] = np.longcomplex
+    _float128t: type[np.generic] = np.longdouble
+    _complex256t: type[np.generic] = np.longcomplex
 else:
     _float128t = np.void
     _complex256t = np.void
@@ -688,7 +687,7 @@ class Nifti1Header(SpmAnalyzeHeader):
     single_magic = b'n+1'
 
     # Quaternion threshold near 0, based on float32 precision
-    quaternion_threshold = -np.finfo(np.float32).eps * 3
+    quaternion_threshold = np.finfo(np.float32).eps * 3
 
     def __init__(self, binaryblock=None, endianness=None, check=True, extensions=()):
         """Initialize header from binary data block and extensions"""
@@ -1817,7 +1816,8 @@ class Nifti1PairHeader(Nifti1Header):
 class Nifti1Pair(analyze.AnalyzeImage):
     """Class for NIfTI1 format image, header pair"""
 
-    header_class: Type[Nifti1Header] = Nifti1PairHeader
+    header_class: type[Nifti1Header] = Nifti1PairHeader
+    header: Nifti1Header
     _meta_sniff_len = header_class.sizeof_hdr
     rw = True
 
