@@ -11,10 +11,10 @@ except ImportError:
     __version__ = '0+unknown'
 
 
-COMMIT_HASH = '323a88ae3'
+COMMIT_HASH = '97457374dc'
 
 
-def _cmp(a, b) -> int:
+def _cmp(a: Version, b: Version) -> int:
     """Implementation of ``cmp`` for Python 3"""
     return (a > b) - (a < b)
 
@@ -101,7 +101,7 @@ def pkg_commit_hash(pkg_path: str | None = None) -> tuple[str, str]:
         return 'archive substitution', COMMIT_HASH
     ver = Version(__version__)
     if ver.local is not None and ver.local.startswith('g'):
-        return ver.local[1:8], 'installation'
+        return 'installation', ver.local[1:8]
     # maybe we are in a repository
     proc = run(
         ('git', 'rev-parse', '--short', 'HEAD'),
@@ -113,7 +113,7 @@ def pkg_commit_hash(pkg_path: str | None = None) -> tuple[str, str]:
     return '(none found)', '<not found>'
 
 
-def get_pkg_info(pkg_path: str) -> dict:
+def get_pkg_info(pkg_path: str) -> dict[str, str]:
     """Return dict describing the context of this package
 
     Parameters
