@@ -227,6 +227,7 @@ class Spm99AnalyzeImage(analyze.AnalyzeImage):
     """Class for SPM99 variant of basic Analyze image"""
 
     header_class = Spm99AnalyzeHeader
+    header: Spm99AnalyzeHeader
     files_types = (('image', '.img'), ('header', '.hdr'), ('mat', '.mat'))
     has_affine = True
     makeable = True
@@ -331,5 +332,5 @@ class Spm99AnalyzeImage(analyze.AnalyzeImage):
             sio.savemat(mfobj, {'M': M, 'mat': mat}, format='4')
 
 
-load = Spm99AnalyzeImage.load
+load = Spm99AnalyzeImage.from_filename
 save = Spm99AnalyzeImage.instance_to_filename
